%define major     1
%define libname   %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

%bcond_without mingw

Name:           uriparser
Version:        0.9.8
Release:        %mkrel 1
Summary:        URI parsing library - RFC 3986
Group:          System/Libraries
License:        BSD-3-Clause
URL:            https://uriparser.github.io/
Source0:        https://github.com/uriparser/%{name}/releases/download/%{name}-%{version}/%{name}-%{version}.tar.bz2

BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  graphviz
BuildRequires:  pkgconfig(gtest)

%if %{with mingw}
BuildRequires:  mingw32-filesystem >= 95
BuildRequires:  mingw32-gcc-c++

BuildRequires:  mingw64-filesystem >= 95
BuildRequires:  mingw64-gcc-c++
%endif

%description
Uriparser is a strictly RFC 3986 compliant URI parsing library written
in C. uriparser is cross-platform, fast, supports Unicode and is
licensed under the New BSD license.

%package -n     %{libname}
Summary:        URI parsing library - RFC 3986
Group:          System/Libraries

%description -n %{libname}
Uriparser is a strictly RFC 3986 compliant URI parsing library written
in C. uriparser is cross-platform, fast, supports Unicode and is
licensed under the New BSD license.

%package -n %{develname}
Summary:        Development files for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package doc
Summary:        HTML documentation for %{name}
Group:          Documentation
BuildArch:      noarch

%description doc
The %{name}-doc package contains HTML documentation files for %{name}.


%if %{with mingw}
%package -n mingw32-%{name}
Summary:       MinGW Windows %{name} library
BuildArch:     noarch

%description -n mingw32-%{name}
MinGW Windows %{name} library.

%package -n mingw64-%{name}
Summary:       MinGW Windows %{name} library
BuildArch:     noarch

%description -n mingw64-%{name}
MinGW Windows %{name} library.

%{?mingw_debug_package}
%endif

%prep
%autosetup -p1

# Remove qhelpgenerator dependency by commenting Doxygen.in:
sed -i 's/GENERATE_QHP\ =\ yes/GENERATE_QHP\ =\ no/g' doc/Doxyfile.in

%build
# Native build
%cmake
%cmake_build

%if %{with mingw}
# MinGW build
%mingw_cmake -DURIPARSER_BUILD_TESTS=OFF -DURIPARSER_BUILD_DOCS=OFF
%mingw_make_build
%endif

%install
%cmake_install

%if %{with mingw}
%mingw_make_install
%mingw_debug_install_post
%endif

%check
%ctest

%files
%doc THANKS AUTHORS ChangeLog
%{_bindir}/uriparse

%files -n %{libname}
%license COPYING
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/lib%{name}.pc
%{_libdir}/cmake/%{name}-%{version}/

%files doc
%license COPYING
%doc %{_docdir}/%{name}/html

%if %{with mingw}
%files -n mingw32-%{name}
%license COPYING
%{mingw32_bindir}/uriparse.exe
%{mingw32_bindir}/lib%{name}-1.dll
%{mingw32_includedir}/%{name}/
%{mingw32_libdir}/lib%{name}.dll.a
%{mingw32_libdir}/pkgconfig/lib%{name}.pc
%{mingw32_libdir}/cmake/%{name}-%{version}/

%files -n mingw64-%{name}
%license COPYING
%{mingw64_bindir}/uriparse.exe
%{mingw64_includedir}/%{name}/
%{mingw64_bindir}/lib%{name}-1.dll
%{mingw64_libdir}/lib%{name}.dll.a
%{mingw64_libdir}/pkgconfig/lib%{name}.pc
%{mingw64_libdir}/cmake/%{name}-%{version}/
%endif


%changelog
* Sun May 05 2024 daviddavid <daviddavid> 0.9.8-1.mga10
+ Revision: 2062365
- new version: 0.9.8

* Sat Dec 23 2023 daviddavid <daviddavid> 0.9.7-1.mga10
+ Revision: 2021018
- initial package uriparser

